@@ -1,9 +1,9 @@
 #  Copyright (c) 2005-2011 by Enthought, Inc.
 #  All rights reserved.
-""" Two-dimensionsal plotting application toolkit.
+""" Two-dimensional plotting application toolkit.
     Part of the Chaco project of the Enthought Tool Suite.
 """
-__version__ = '4.0.0'
+__version__ = '4.1.0'
 
 __requires__ = [
    'enable',
